@@ -326,12 +326,17 @@ class RestChannelAsyncClient:
 
                 try:
                     resp = _post(self._server_url, self._headers, RestChannelRequest.make_heartbeat())
+                    err = None
                 except Exception as e:
                     resp = None
-                    if self._on_hb_error:
-                        self._on_hb_error(e)
-                    else:
-                        _logger.error(f'Error during sending heartbeat [error={e}]', exc_info=True)
+                    err = e
+
+            if err:
+                if self._on_hb_error:
+                    self._on_hb_error(e)
+                else:
+                    _logger.error(f'Error during sending heartbeat [error={e}]', exc_info=True)
+
             self._on_srv_messages(resp)
 
 
